@@ -21,9 +21,13 @@
 #'  present or if time-to-event outcome, must be provided.
 #' @param shift A two argument function that specifies how treatment variables should be shifted.
 #'  See examples for how to specify shift functions for continuous, binary, and categorical exposures.
+#' @param shifted An optional data frame, the same as in \code{data}, but modified according
+#'  to the treatment policy of interest. If specified, \code{shift} is ignored.
 #' @param k An integer specifying how previous time points should be
 #'  used for estimation at the given time point. Default is \code{Inf},
 #'  all time points.
+#' @param intervention_type The intervention type, should be one of \code{"static"},
+#'   \code{"dynamic"}, \code{"mtp"}.
 #' @param outcome_type Outcome variable type (i.e., continuous, binomial, survival).
 #' @param id An optional column name containing cluster level identifiers.
 #' @param bounds An optional vector of the bounds for continuous outcomes. If \code{NULL},
@@ -36,8 +40,6 @@
 #' @param folds The number of folds to be used for cross-fitting. Minimum allowable number
 #' is two folds.
 #' @param weights An optional vector of length n containing sampling weights.
-#' @param return_all_ratios Logical. If \code{TRUE}, the non-cumulative product density
-#'  ratios will be returned. The default is \code{FALSE}.
 #' @param .bound Determines that maximum and minimum values (scaled) predictions
 #'  will be bounded by. The default is 1e-5, bounding predictions by 1e-5 and 0.9999.
 #' @param .trim Determines the amount the density ratios should be trimmed.
@@ -58,8 +60,6 @@
 #' \item{outcome_reg}{An n x Tau + 1 matrix of outcome regression predictions.
 #'  The mean of the first column is used for calculating theta.}
 #' \item{density_ratios}{An n x Tau matrix of the estimated density ratios.}
-#' \item{raw_ratios}{An n x Tau matrix of the estimated non-cumulative product density ratios.
-#'  \code{NULL} if \code{return_all_ratios = FALSE}.}
 #' \item{weights_m}{A list the same length as \code{folds}, containing the Super Learner
 #'  ensemble weights at each time-point for each fold for the outcome regression.}
 #' \item{weights_r}{A list the same length as \code{folds}, containing the Super Learner
@@ -68,12 +68,12 @@
 #'
 #' @example inst/examples/tmle-ex.R
 #' @export
-lmtp_tmle <- function(data, trt, outcome, baseline = NULL,
-                      time_vary = NULL, cens = NULL, shift, k = Inf,
+lmtp_tmle <- function(data, trt, outcome, baseline = NULL, time_vary = NULL,
+                      cens = NULL, shift = NULL, shifted = NULL, k = Inf,
+                      intervention_type = c("static", "dynamic", "mtp"),
                       outcome_type = c("binomial", "continuous", "survival"),
                       id = NULL, bounds = NULL, learners_outcome = "SL.glm",
                       learners_trt = "SL.glm", folds = 10, weights = NULL,
-                      return_all_ratios = FALSE,
                       .bound = 1e-5, .trim = 0.999, .SL_folds = 10) {
   meta <- Meta$new(
     data = data,
@@ -84,6 +84,7 @@ lmtp_tmle <- function(data, trt, outcome, baseline = NULL,
     cens = cens,
     k = k,
     shift = shift,
+    shifted = shifted,
     learners_trt = learners_trt,
     learners_outcome = learners_outcome,
     id = id,
@@ -96,35 +97,54 @@ lmtp_tmle <- function(data, trt, outcome, baseline = NULL,
 
   pb <- progressr::progressor(meta$tau*folds*2)
 
-  ratios <- cf_r(meta$data, shift, folds, meta$trt, cens, meta$risk, meta$tau,
-                 meta$node_list$trt, learners_trt, pb, meta$weights_r, .SL_folds)
-  cumprod_ratios <- ratio_dr(ratios, folds, .trim)
+  ratios <- cf_r(
+    meta$data, meta$shifted_data,
+    meta$folds, meta$trt,
+    cens, meta$risk, meta$tau,
+    meta$node_list$trt, learners_trt,
+    pb, meta$weights_r,
+    match.arg(intervention_type),
+    .SL_folds,
+    .trim
+  )
 
-  estims <-
-    cf_tmle(meta$data, meta$shifted_data, folds, "xyz", meta$node_list$outcome,
-            cens, meta$risk, meta$tau, meta$outcome_type, meta$m, meta$m,
-            cumprod_ratios, learners_outcome, pb, meta$weights, meta$weights_m, .SL_folds)
+  estims <- cf_tmle(
+    meta$data,
+    meta$shifted_data,
+    meta$folds,
+    "xyz", # CHANGE THIS TO "*tmp_lmtp_outcome*",
+    cens,
+    meta$risk,
+    meta$tau,
+    meta$node_list$outcome,
+    meta$outcome_type,
+    meta$m, meta$m,
+    ratio_tmle_ipw(ratios),
+    learners_outcome,
+    meta$weights,
+    meta$weights_m,
+    .SL_folds,
+    pb
+  )
 
-  out <- compute_theta(
-    estimator = "tml",
-    eta = list(
+  theta_dr(
+    list(
       estimator = "TMLE",
-      m = estims,
-      r = recombine_dens_ratio(cumprod_ratios),
-      raw_ratios = if (return_all_ratios) recombine_raw_ratio(ratios),
+      m = list(natural = estims$natural, shifted = estims$shifted),
+      r = ratios$ratios,
       tau = meta$tau,
       folds = meta$folds,
       id = meta$id,
       outcome_type = meta$outcome_type,
       bounds = meta$bounds,
       weights = weights,
-      shift = deparse(substitute((shift))),
-      weights_m = pluck_weights("m", estims),
-      weights_r = pluck_weights("r", cumprod_ratios),
+      shift = if (is.null(shifted)) deparse(substitute((shift))) else NULL,
+      weights_m = estims$sl_weights,
+      weights_r = ratios$sl_weights,
       outcome_type = meta$outcome_type
-    ))
-
-  return(out)
+    ),
+    FALSE
+  )
 }
 
 #' LMTP Sequential Doubly Robust Estimator
@@ -150,9 +170,13 @@ lmtp_tmle <- function(data, trt, outcome, baseline = NULL,
 #'  present or if time-to-event outcome, must be provided.
 #' @param shift A two argument function that specifies how treatment variables should be shifted.
 #'  See examples for how to specify shift functions for continuous, binary, and categorical exposures.
+#' @param shifted An optional data frame, the same as in \code{data}, but modified according
+#'  to the treatment policy of interest. If specified, \code{shift} is ignored.
 #' @param k An integer specifying how previous time points should be
 #'  used for estimation at the given time point. Default is \code{Inf},
 #'  all time points.
+#' @param intervention_type The intervetion type, should be one of \code{"static"},
+#'   \code{"dynamic"}, \code{"mtp"}.
 #' @param outcome_type Outcome variable type (i.e., continuous, binomial, survival).
 #' @param id An optional column name containing cluster level identifiers.
 #' @param bounds An optional vector of the bounds for continuous outcomes. If \code{NULL},
@@ -165,8 +189,6 @@ lmtp_tmle <- function(data, trt, outcome, baseline = NULL,
 #' @param folds The number of folds to be used for cross-fitting. Minimum allowable number
 #' is two folds.
 #' @param weights An optional vector of length n containing sampling weights.
-#' @param return_all_ratios Logical. If \code{TRUE}, the non-cumulative product density
-#'  ratios will be returned. The default is \code{FALSE}.
 #' @param .bound Determines that maximum and minimum values (scaled) predictions
 #'  will be bounded by. The default is 1e-5, bounding predictions by 1e-5 and 0.9999.
 #' @param .trim Determines the amount the density ratios should be trimmed.
@@ -187,8 +209,6 @@ lmtp_tmle <- function(data, trt, outcome, baseline = NULL,
 #' \item{outcome_reg}{An n x Tau + 1 matrix of outcome regression predictions.
 #'  The mean of the first column is used for calculating theta.}
 #' \item{density_ratios}{An n x Tau matrix of the estimated density ratios.}
-#' \item{raw_ratios}{An n x Tau matrix of the estimated non-cumulative product density ratios.
-#'  \code{NULL} if \code{return_all_ratios = FALSE}.}
 #' \item{weights_m}{A list the same length as \code{folds}, containing the Super Learner
 #'  ensemble weights at each time-point for each fold for the outcome regression.}
 #' \item{weights_r}{A list the same length as \code{folds}, containing the Super Learner
@@ -197,12 +217,12 @@ lmtp_tmle <- function(data, trt, outcome, baseline = NULL,
 #' @export
 #'
 #' @example inst/examples/sdr-ex.R
-lmtp_sdr <- function(data, trt, outcome, baseline = NULL,
-                     time_vary = NULL, cens = NULL, shift, k = Inf,
+lmtp_sdr <- function(data, trt, outcome, baseline = NULL, time_vary = NULL,
+                     cens = NULL, shift = NULL, shifted = NULL, k = Inf,
+                     intervention_type = c("static", "dynamic", "mtp"),
                      outcome_type = c("binomial", "continuous", "survival"),
                      id = NULL, bounds = NULL, learners_outcome = "SL.glm",
                      learners_trt = "SL.glm", folds = 10, weights = NULL,
-                     return_all_ratios = FALSE,
                      .bound = 1e-5, .trim = 0.999, .SL_folds = 10) {
   meta <- Meta$new(
     data = data,
@@ -213,6 +233,7 @@ lmtp_sdr <- function(data, trt, outcome, baseline = NULL,
     cens = cens,
     k = k,
     shift = shift,
+    shifted = shifted,
     learners_trt = learners_trt,
     learners_outcome = learners_outcome,
     id = id,
@@ -225,34 +246,55 @@ lmtp_sdr <- function(data, trt, outcome, baseline = NULL,
 
   pb <- progressr::progressor(meta$tau*folds*2)
 
-  ratios <- cf_r(meta$data, shift, folds, meta$trt, cens, meta$risk, meta$tau,
-                 meta$node_list$trt, learners_trt, pb, meta$weights_r, .SL_folds)
+  ratios <- cf_r(
+    meta$data, meta$shifted_data,
+    meta$folds, meta$trt,
+    cens, meta$risk, meta$tau,
+    meta$node_list$trt, learners_trt,
+    pb, meta$weights_r,
+    match.arg(intervention_type),
+    .SL_folds,
+    .trim
+  )
 
   estims <-
-    cf_sdr(meta$data, meta$shifted_data, folds, "xyz", meta$node_list$outcome,
-           cens, meta$risk, meta$tau, meta$outcome_type, meta$m, meta$m,
-           ratios, learners_outcome, pb, meta$weights_m, .trim, .SL_folds)
+    cf_sdr(
+      meta$data,
+      meta$shifted_data,
+      meta$folds,
+      "xyz",
+      cens,
+      meta$risk,
+      meta$tau,
+      meta$node_list$outcome,
+      meta$outcome_type,
+      meta$m, meta$m,
+      ratios$ratios,
+      learners_outcome,
+      meta$weights,
+      meta$weights_m,
+      .SL_folds,
+      pb
+    )
 
-  out <- compute_theta(
-    estimator = "sdr",
-    eta = list(
+  theta_dr(
+    list(
       estimator = "SDR",
-      m = estims,
-      r = recombine_dens_ratio(ratio_dr(ratios, folds, .trim)),
-      raw_ratios = if (return_all_ratios) recombine_raw_ratio(ratios),
+      m = list(natural = estims$natural, shifted = estims$shifted),
+      r = ratios$ratios,
       tau = meta$tau,
       folds = meta$folds,
-      weights = weights,
       id = meta$id,
       outcome_type = meta$outcome_type,
       bounds = meta$bounds,
-      shift = deparse(substitute((shift))),
-      weights_m = pluck_weights("m", estims),
-      weights_r = pluck_weights("r", ratios),
+      weights = weights,
+      shift = if (is.null(shifted)) deparse(substitute((shift))) else NULL,
+      weights_m = estims$sl_weights,
+      weights_r = ratios$sl_weights,
       outcome_type = meta$outcome_type
-    ))
-
-  return(out)
+    ),
+    TRUE
+  )
 }
 
 #' LMTP Substitution Estimator
@@ -278,6 +320,8 @@ lmtp_sdr <- function(data, trt, outcome, baseline = NULL,
 #'  present or if time-to-event outcome, must be provided.
 #' @param shift A two argument function that specifies how treatment variables should be shifted.
 #'  See examples for how to specify shift functions for continuous, binary, and categorical exposures.
+#' @param shifted An optional data frame, the same as in \code{data}, but modified according
+#'  to the treatment policy of interest. If specified, \code{shift} is ignored.
 #' @param k An integer specifying how previous time points should be
 #'  used for estimation at the given time point. Default is \code{Inf},
 #'  all time points.
@@ -312,8 +356,8 @@ lmtp_sdr <- function(data, trt, outcome, baseline = NULL,
 #' @export
 #'
 #' @example inst/examples/sub-ex.R
-lmtp_sub <- function(data, trt, outcome, baseline = NULL,
-                     time_vary = NULL, cens = NULL, shift, k = Inf,
+lmtp_sub <- function(data, trt, outcome, baseline = NULL, time_vary = NULL, cens = NULL,
+                     shift = NULL, shifted = NULL, k = Inf,
                      outcome_type = c("binomial", "continuous", "survival"),
                      id = NULL, bounds = NULL, learners = "SL.glm", folds = 10,
                      weights = NULL, .bound = 1e-5, .SL_folds = 10) {
@@ -326,6 +370,7 @@ lmtp_sub <- function(data, trt, outcome, baseline = NULL,
     cens = cens,
     k = k,
     shift = shift,
+    shifted = shifted,
     learners_trt = NULL,
     learners_outcome = learners,
     id = id,
@@ -338,25 +383,35 @@ lmtp_sub <- function(data, trt, outcome, baseline = NULL,
 
   pb <- progressr::progressor(meta$tau*folds)
 
-  estims <- cf_sub(meta$data, meta$shifted_data, folds, "xyz",
-                   meta$node_list$outcome,
-                   cens, meta$risk, meta$tau, meta$outcome_type,
-                   learners, meta$m, pb, meta$weights_m, .SL_folds)
+  estims <- cf_sub(
+    meta$data,
+    meta$shifted_data,
+    meta$folds,
+    "xyz",
+    meta$node_list$outcome,
+    cens,
+    meta$risk,
+    meta$tau,
+    meta$outcome_type,
+    learners,
+    meta$m,
+    pb,
+    meta$weights_m,
+    .SL_folds
+  )
 
-  out <- compute_theta(
-    estimator = "sub",
+  theta_sub(
     eta = list(
       m = estims$m,
       outcome_type = meta$outcome_type,
       bounds = meta$bounds,
       folds = meta$folds,
       weights = weights,
-      shift = deparse(substitute((shift))),
-      weights_m = pluck_weights("m", estims),
+      shift = if (is.null(shifted)) deparse(substitute((shift))) else NULL,
+      weights_m = estims$sl_weights,
       outcome_type = meta$outcome_type
-    ))
-
-  return(out)
+    )
+  )
 }
 
 #' LMTP IPW Estimator
@@ -382,6 +437,10 @@ lmtp_sub <- function(data, trt, outcome, baseline = NULL,
 #'  present or if time-to-event outcome, must be provided.
 #' @param shift A two argument function that specifies how treatment variables should be shifted.
 #'  See examples for how to specify shift functions for continuous, binary, and categorical exposures.
+#' @param shifted An optional data frame, the same as in \code{data}, but modified according
+#'  to the treatment policy of interest. If specified, \code{shift} is ignored.
+#' @param intervention_type The intervetion type, should be one of \code{"static"},
+#'   \code{"dynamic"}, \code{"mtp"}.
 #' @param outcome_type Outcome variable type (i.e., continuous, binomial, survival).
 #' @param k An integer specifying how previous time points should be
 #'  used for estimation at the given time point. Default is \code{Inf},
@@ -392,8 +451,6 @@ lmtp_sub <- function(data, trt, outcome, baseline = NULL,
 #' @param folds The number of folds to be used for cross-fitting. Minimum allowable number
 #'  is two folds.
 #' @param weights An optional vector of length n containing sampling weights.
-#' @param return_all_ratios Logical. If \code{TRUE}, the non-cumulative product density
-#'  ratios will be returned. The default is \code{FALSE}.
 #' @param .bound Determines that maximum and minimum values (scaled) predictions
 #'  will be bounded by. The default is 1e-5, bounding predictions by 1e-5 and 0.9999.
 #' @param .trim Determines the amount the density ratios should be trimmed.
@@ -411,18 +468,17 @@ lmtp_sub <- function(data, trt, outcome, baseline = NULL,
 #' \item{high}{NA}
 #' \item{shift}{The shift function specifying the treatment policy of interest.}
 #' \item{density_ratios}{An n x Tau matrix of the estimated density ratios.}
-#' \item{raw_ratios}{An n x Tau matrix of the estimated non-cumulative product density ratios.
-#'  \code{NULL} if \code{return_all_ratios = FALSE}.}
 #' \item{weights_r}{A list the same length as \code{folds}, containing the Super Learner
 #'  ensemble weights at each time-point for each fold for the propensity.}
 #' @export
 #'
 #' @example inst/examples/ipw-ex.R
-lmtp_ipw <- function(data, trt, outcome, baseline = NULL,
-                     time_vary = NULL, cens = NULL, k = Inf,
-                     id = NULL, shift, outcome_type = c("binomial", "continuous", "survival"),
+lmtp_ipw <- function(data, trt, outcome, baseline = NULL, time_vary = NULL, cens = NULL,
+                     shift = NULL, shifted = NULL,
+                     intervention_type = c("static", "dynamic", "mtp"),
+                     outcome_type = c("binomial", "continuous", "survival"),
+                     k = Inf, id = NULL,
                      learners = "SL.glm", folds = 10, weights = NULL,
-                     return_all_ratios = FALSE,
                      .bound = 1e-5, .trim = 0.999, .SL_folds = 10) {
   meta <- Meta$new(
     data = data,
@@ -433,6 +489,7 @@ lmtp_ipw <- function(data, trt, outcome, baseline = NULL,
     cens = cens,
     k = k,
     shift = shift,
+    shifted = shifted,
     learners_trt = learners,
     learners_outcome = NULL,
     id = id,
@@ -445,16 +502,20 @@ lmtp_ipw <- function(data, trt, outcome, baseline = NULL,
 
   pb <- progressr::progressor(meta$tau*folds)
 
-  ratios <- cf_r(meta$data, shift, folds, meta$trt, cens, meta$risk,
-                 meta$tau, meta$node_list$trt, learners, pb, meta$weights_r,
-                 .SL_folds)
-  cumprod_ratios <- ratio_ipw(recombine_ipw(ratios), .trim)
+  ratios <- cf_r(
+    meta$data, meta$shifted_data,
+    meta$folds, meta$trt,
+    cens, meta$risk, meta$tau,
+    meta$node_list$trt, learners,
+    pb, meta$weights_r,
+    match.arg(intervention_type),
+    .SL_folds,
+    .trim
+  )
 
-  out <- compute_theta(
-    estimator = "ipw",
+  theta_ipw(
     eta = list(
-      r = cumprod_ratios$r,
-      raw_ratios = if (return_all_ratios) recombine_raw_ratio(ratios),
+      r = ratio_tmle_ipw(ratios),
       y = if (meta$survival) {
         convert_to_surv(data[[final_outcome(outcome)]])
       } else {
@@ -463,9 +524,8 @@ lmtp_ipw <- function(data, trt, outcome, baseline = NULL,
       folds = meta$folds,
       weights = weights,
       tau = meta$tau,
-      shift = deparse(substitute((shift))),
-      weights_r = cumprod_ratios$sl_weights
-    ))
-
-  return(out)
+      shift = if (is.null(shifted)) deparse(substitute((shift))) else NULL,
+      weights_r = ratios$sl_weights
+    )
+  )
 }
