@@ -4,30 +4,26 @@ context("Fidelity of estimates with censoring")
 a <- c("A1", "A2")
 nodes <- list(c("L1"), c("L2"))
 cens <- c("C1", "C2")
-truth <- 0.88
-
-rule <- function(data, x) {
-  data[[x]] + 0.5
-}
+truth <- 0.8
 
 sub <-
   sw(lmtp_sub(sim_cens, a, "Y", nodes, baseline = NULL,
-              cens, k = 0, shift = rule,
+              cens, k = 0, shift = NULL,
               outcome_type = "binomial",
               folds = 2))
 
 ipw <-
   sw(lmtp_ipw(sim_cens, a, "Y", NULL, nodes,
-              cens, k = 0, shift = rule, folds = 2))
+              cens, k = 0, shift = NULL, folds = 2))
 
 tmle <-
     sw(lmtp_tmle(sim_cens, a, "Y", nodes, baseline = NULL,
-              cens, k = 0, shift = rule,
+              cens, k = 0, shift = NULL,
               outcome_type = "binomial", folds = 2))
 
 sdr <-
   sw(lmtp_sdr(sim_cens, a, "Y", nodes, baseline = NULL,
-           cens, k = 0, shift = rule,
+           cens, k = 0, shift = NULL,
            outcome_type = "binomial", folds = 2))
 
 # tests
